//
//  URIParser.h
//
//  Created by Setsu on 4/26/10.
//  Copyright 2010 RoundSquare Inc. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person or organization
// obtaining a copy of the software and accompanying documentation covered by
// this license (the "Software") to use, reproduce, display, distribute,
// execute, and transmit the Software, and to prepare derivative works of the
// Software, and to permit third-parties to whom the Software is furnished to
// do so, all subject to the following:
// 
// The copyright notices in the Software and this entire statement, including
// the above license grant, this restriction and the following disclaimer,
// must be included in all copies of the Software, in whole or in part, and
// all derivative works of the Software, unless such copies or derivative
// works are solely in the form of machine-executable object code generated by
// a source language processor.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
// FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

#ifndef URI_PARSER_H
#define URI_PARSER_H

//----------------------------------------
//	include
//----------------------------------------
#include <string>
#include <vector>
#include <map>
#include <memory>

//----------------------------------------
//	URIParser
//----------------------------------------
class URIParser
{
public:
	URIParser(const std::string& urlStr);
	~URIParser();
	int GetURL(std::string& url) const;

	const std::string& getScheme() const;
	const std::string& getUserInfo() const;
	const std::string& getHost() const;
	unsigned short getPort() const;
	std::string getAuthority() const;
	const std::string& getPath() const;
	std::string getQuery() const;
	const std::string& getFragment() const;

	void getPathSegments(std::vector<std::string>& segments);
	void getQueryMap(std::map<std::string, std::string>& keyValues) const;

private:
	URIParser();
	URIParser(const URIParser&);
	URIParser& operator = (const URIParser&);

	class URIParserImpl;
	std::auto_ptr<URIParserImpl>	m_pImpl;
};

#endif	// URI_PARSER_H
