//
//  URIParserTest.cpp
//
//  Created  by Setsu on 4/26/10.
//  Modified by Setsu on May 30, 2013.
//  Copyright 2010-2013 RoundSquare Inc. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person or organization
// obtaining a copy of the software and accompanying documentation covered by
// this license (the "Software") to use, reproduce, display, distribute,
// execute, and transmit the Software, and to prepare derivative works of the
// Software, and to permit third-parties to whom the Software is furnished to
// do so, all subject to the following:
// 
// The copyright notices in the Software and this entire statement, including
// the above license grant, this restriction and the following disclaimer,
// must be included in all copies of the Software, in whole or in part, and
// all derivative works of the Software, unless such copies or derivative
// works are solely in the form of machine-executable object code generated by
// a source language processor.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
// FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

//----------------------------------------
//	include
//----------------------------------------
#include <Poco/Format.h>

#include "ScopedLogMessage.h"
#include "PrepareConsoleLogger.h"
#include "URIParser.h"

//----------------------------------------
//	ParseURI
//----------------------------------------
void ParseURI(const std::string& sourceUri)
{
	ScopedLogMessage msg("ParseURI ", "start", "end");

	msg.Message(Poco::format(" sourceUri = %s", sourceUri));

	URIParser parser(sourceUri);

	msg.Message(Poco::format("    scheme = %s", parser.getScheme()));
	msg.Message(Poco::format("  userInfo = %s", parser.getUserInfo()));
	msg.Message(Poco::format("      host = %s", parser.getHost()));
	msg.Message(Poco::format("      port = %hu", parser.getPort()));
	msg.Message(Poco::format(" authority = %s", parser.getAuthority()));
	msg.Message(Poco::format("      path = %s", parser.getPath()));

	std::vector<std::string> pathSegments;
	parser.getPathSegments(pathSegments);
	for(std::vector<std::string>::iterator itr=pathSegments.begin(); itr!=pathSegments.end(); ++itr)
	{
		int count = 0;
		msg.Message(Poco::format("             path[%d] = %s", count++, *itr));
	}

	msg.Message(Poco::format("     query = %s", parser.getQuery()));

	std::map<std::string, std::string> keyValues;
	parser.getQueryMap(keyValues);
	if(0 != keyValues.size())
	{
		int count = 0;
		for(std::map<std::string, std::string>::iterator itr=keyValues.begin(); itr!=keyValues.end(); ++itr)
		{
			msg.Message(Poco::format("             query[%d] = (%s, %s)", count++, itr->first, itr->second));
		}
	}
	msg.Message(Poco::format("  fragment = %s", parser.getFragment()));
}

//----------------------------------------
//	main
//----------------------------------------
int main(int /*argc*/, char** /*argv*/)
{
	PrepareConsoleLogger logger(Poco::Logger::ROOT, Poco::Message::PRIO_INFORMATION);

	ParseURI("http://www.google.co.jp/search?source=ig&hl=ja&rlz=&q=POCO+Fanatic&meta=lr%3D&aq=f&aqi=&aql=&oq=&gs_rfai=");

	return 0;
}
